@@ -2,45 +2,26 @@ package Alien::Build::Plugin::Probe::Vcpkg;
 
 use strict;
 use warnings;
-use 5.008004;
 use Alien::Build::Plugin;
 
 # ABSTRACT: Probe for system libraries using Vcpkg
-our $VERSION = '2.82_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '2.11'; # VERSION
 
 
 has '+name';
 has 'lib';
-has 'ffi_name';
-has 'include';
 
 sub init
 {
   my($self, $meta) = @_;
 
-  if(defined $self->include)
-  {
-    $meta->add_requires('configure' => 'Alien::Build::Plugin::Probe::Vcpkg' => '2.16' );
-  }
-  elsif(defined $self->ffi_name)
-  {
-    $meta->add_requires('configure' => 'Alien::Build::Plugin::Probe::Vcpkg' => '2.14' );
-  }
-  else
-  {
-    $meta->add_requires('configure' => 'Alien::Build::Plugin::Probe::Vcpkg' => '0' );
-  }
+  $meta->add_requires('configure' => 'Alien::Build::Plugin::Probe::Vcpkg' => 0 );
 
   if($meta->prop->{platform}->{compiler_type} eq 'microsoft')
   {
     $meta->register_hook(
       probe => sub {
         my($build) = @_;
-
-        $build->hook_prop->{probe_class} = __PACKAGE__;
-        $build->hook_prop->{probe_instance_id} = $self->instance_id;
-
         eval {
           require Win32::Vcpkg;
           require Win32::Vcpkg::List;
@@ -57,11 +38,11 @@ sub init
         if($self->name)
         {
           $package = Win32::Vcpkg::List->new
-                                       ->search($self->name, include => $self->include);
+                                       ->search($self->name);
         }
         elsif($self->lib)
         {
-          $package = eval { Win32::Vcpkg::Package->new( lib => $self->lib, include => $self->include) };
+          $package = eval { Win32::Vcpkg::Package->new( lib => $self->lib ) };
           return 'share' if $@;
         }
         else
@@ -73,14 +54,11 @@ sub init
         my $version = $package->version;
         $version = 'unknown' unless defined $version;
 
-        $build->install_prop->{plugin_probe_vcpkg}->{$self->instance_id} = {
-          version  => $version,
-          cflags   => $package->cflags,
-          libs     => $package->libs,
+        $build->install_prop->{plugin_probe_vcpkg} = {
+          version => $version,
+          cflags  => $package->cflags,
+          libs    => $package->libs,
         };
-        $build->hook_prop->{version} = $version;
-        $build->install_prop->{plugin_probe_vcpkg}->{$self->instance_id}->{ffi_name} = $self->ffi_name
-          if defined $self->ffi_name;
         return 'system';
       },
     );
@@ -88,14 +66,10 @@ sub init
     $meta->register_hook(
       gather_system => sub {
         my($build) = @_;
-
-        return if $build->hook_prop->{name} eq 'gather_system'
-        &&        ($build->install_prop->{system_probe_instance_id} || '') ne $self->instance_id;
-
-        if(my $c = $build->install_prop->{plugin_probe_vcpkg}->{$self->instance_id})
+        if(my $c = $build->install_prop->{plugin_probe_vcpkg})
         {
           $build->runtime_prop->{version} = $c->{version} unless defined $build->runtime_prop->{version};
-          $build->runtime_prop->{$_} = $c->{$_} for grep { defined $c->{$_} } qw( cflags libs ffi_name );
+          $build->runtime_prop->{$_} = $c->{$_} for qw( cflags libs );
         }
       },
     );
@@ -116,7 +90,7 @@ Alien::Build::Plugin::Probe::Vcpkg - Probe for system libraries using Vcpkg
 
 =head1 VERSION
 
-version 2.82_01
+version 2.11
 
 =head1 SYNOPSIS
 
@@ -192,10 +166,6 @@ This must be an array reference.  Do not include the C<.lib> extension.
 
  plugin 'Probe::Vcpkg' => (lib => ['foo','bar']);
 
-=head2 ffi_name
-
-Specifies an alternate ffi_name for finding dynamic libraries.
-
 =head1 SEE ALSO
 
 L<Alien::Build>, L<alienfile>, L<Alien::Build::MM>, L<Alien>
@@ -242,7 +212,7 @@ Juan Julián Merelo Guervós (JJ)
 
 Joel Berger (JBERGER)
 
-Petr Písař (ppisar)
+Petr Pisar (ppisar)
 
 Lance Wicks (LANCEW)
 
@@ -258,15 +228,9 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
-Håkon Hægland (hakonhagland, HAKONH)
-
-nick nauwelaerts (INPHOBIA)
-
-Florian Weimer
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2022 by Graham Ollis.
+This software is copyright (c) 2011-2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
